* VERSION 1.0
* FIRST VERSION: MAY 15, 2006
* THIS VERSION:  MAY 15, 2006
* LAST REVISOR: SOB
*

# delimit ;

capture log close;
clear;

cd "$rootcafe";
log using "logs/displacement-logit-$par.log", replace;
adopath + "$root/%stata/ado"; 

set matsize 800;
set more off;
set rmsg on;
set seed 1234;

capture mkdir "$rootcafe/estmat/$par";
capture mkdir "$rootcafe/Xdata/$par";

*-----------------------------------------------;
capture program drop memuse;
program define memuse;
   qui memory;
   local memused = round(_N * `r(width)' / (1024*1024));
   local memsize = round(`r(M_total)' / (1024*1024));
   display in ye "`memused' MB of `memsize' MB allocated memory in use";
end;
*-----------------------------------------------;

use "$root/xba/FDI-worker-data/displacement-probit-worker-sample-$rsample", clear;

memuse; /* nonmf: 33 MB of 500 MB for 2% sample */

drop d_employmtg_1999_1998_*;

memuse; /* nonmf: 30 MB of 500 MB for 2% sample */

if "$par" == "manf" {;
   keep if dwz93g8_3==1;
};

if "$par" == "nonmf" {;
   drop if dwz93g8_3==1;
};

memuse; /* nonmf: 19 MB of 500 MB for 2% sample */

/* in fdiselct: 
if "$par" == "manf" {
  keep if sec1_aggbem>=2 & sec1_aggbem<=4
  }
if "$par" == "nonmf" {
  drop if sec1_aggbem>=2 & sec1_aggbem<=4
  }
*/

*--------------------------------------------------------------------------------------------;




*--------------------------------------------------------------------------------------------;

global workervars "age age2 ln_wage female emplminor emplother wcollar abiormore apprentice parttime";
global lagvars    "lag_ln_wage lag_nemp";

tsunab plantvars: east nemp dwz93g8_2-dwz93g8_8 p_*;
global plantvars "`plantvars'";

tsunab nonustanvars: $workervars $plantvars $lagvars;
global nonustanvars "`nonustanvars'";

*---------------------------------------------------------------------------------------------;
* Note: Ustan vars fixdasst (capital stock), turnover (output) and value-added in p.c. terms  ;
* par_fixdasst, par_turnover and par_valueadd are in thsd of Euros and are already deflated!! ;
* par_employment is in plain numbers, i.e. NOT in thousands !!!                               ;
*---------------------------------------------------------------------------------------------;
*tsunab ustanvars: par_turnover* par_employmt* par_fixdasst*;
tsunab ustanvars: par_*99;
global ustanvars "`ustanvars'";

tsunab treatvars: employ* d_employ*;
global treatvars "`treatvars'";

tsunab employmtlvls99: employmt_1999_???; /* regions 3-digit code (APC, CEE etc), world-wide 2-digit (WW) */
global employmtlvls99 "`employmtlvls99'";
*global employmtlvls99 = regexr("$employmtlvls99","employmt_1999_ALL","");

foreach var of global nonustanvars {;
   gen eWW99_`var' = employmt_1999_WW * `var';
};

tsunab inonustanvars: eWW99*;
global inonustanvars "`inonustanvars'";

tsunab expansionvars: d_employmtg_2000_1999_???;
global expansionvars "`expansionvars'";

*--------------------------------------------------------------------------------------------;
*--------------------------------------------------------------------------------------------;

/* specifications remarks */
/**************************/
/* Remarks:
1) Since Ustan information is only available for FDI workers/plants, cannot use Ustan vars 
   in specifications where FDI status is the treatment.
2) */

/**************************************************************************/
/* sample type 1: MNEs and non-MNEs,  without (!) Ustan vars              */
/* variables displace d_employmtg_1999_1999 $employmtlvls99 $nonustanvars */
/* have been cleaned up in displacement-pscore-sample.do                  */
/**************************************************************************/
*---------------------------------------------------------------------------------------------;

foreach sample in 1 2 {; /* begin of foreach sample */
   
   if `sample' == 2 {; 
   /**************************************************************************/
   /* sample type 2: MNEs only, without (!) Ustan vars                       */
   /* variables displace d_employmtg_2000_1999 $employmtlvls99 $nonustanvars */
   /* have been cleaned up in displacement-pscore-sample.do                  */
   /**************************************************************************/
   
      foreach region in WW APC CEE EMU ODV OIN OWE RCA {; /* begin of foreach region */

         gen d_employmtg_2000_1999_`region'_intmrg = (employmtg_2000_1999_`region'>0) & (employmt_1999_`region'>0);
         rename d_employmtg_2000_1999_`region' d_employmtg_2000_1999_`region'_uncond;
         rename d_employmtg_2000_1999_`region'_intmrg d_employmtg_2000_1999_`region';
      
      };
      
   }; /* end of if sample==2 */

   /* pstest statistics
   r(meanbiasbef) and r(meanbiasaft) the mean absolute standardised bias, 
   r(medbiasbef) and r(medbiasaft) the median absolute standardised bias, 
   r(r2bef) and r(r2aft) the pseudo R2 from probit estimation and 
   r(chiprobbef) and r(chiprobaft) the P-value of the likelihood-ratio test.
   */

   foreach spec in 1 2 3 4 {; /* begin of foreach spec */

	
	   if `spec'==1 {;
	      global controllist "$employmtlvls99 $workervars";
	   };
	   else if `spec'==2 {;
	      global controllist "$employmtlvls99 $workervars $plantvars";
	   };
	   else if `spec'==3 {;
	      global controllist "$employmtlvls99 $nonustanvars";
	   };
	   else if `spec'==4 {;
	      global controllist "$employmtlvls99 $nonustanvars $inonustanvars"; 
	   };


      di _newline(2) "Sample `sample', ALL REGIONS, Specification `spec'";
      di _newline    "*************************************************************";

      
      logit separate $expansionvars $controllist, or; 
		mfx;
		est2vec allreglogit_s`sample'_spec`spec', e(r2_p);

*------------------------------------------------------------------------------------------------;

   }; /* end of foreach spec */

*------------------------------------------------------------------------------------------------;

}; /* end of foreach sample */

*------------------------------------------------------------------------------------------------;

/******************************************************/
/* sample type 3: MNEs in FDI-Ustan intersection only */
/******************************************************/
/* drop workers/plants that are not in the FDI-Ustan intersection */

keep if fdiustan==1;

*--------------------------------------------------------------------------------------------;
count;
memuse; /* nonmf: 1 MB of 500 MB for 2% sample */
*--------------------------------------------------------------------------------------------;

/* make sure Ustan variables are always defined */
/************************************************/
foreach var of global ustanvars {;
      keep if `var'!=.;
};

*---------------------------------------------------------------------------------------------;
memuse; /* nonmf: 1 MB of 500 MB for 2% sample */
count;
local sample = 3;

foreach var of global nonustanvars {;
   gen eHOM99_`var' = par_employmt_99 * `var';
   gen fHOM99_`var' = par_fixdasst_99 * `var';
   gen tHOM99_`var' = par_turnover_99 * `var';
};
memuse; /* nonmf: 1 MB of 500 MB for 2% sample */

tsunab iustanvars: eHOM99* fHOM99* tHOM99*;
global iustanvars "`iustanvars'";

*------------------------------------------------------------------------------------------------;

foreach region in WW APC CEE EMU ODV OIN OWE RCA {; /* begin of foreach region */

   rename d_employmtg_2000_1999_`region' d_employmtg_2000_1999_`region'_intmrg;
   rename d_employmtg_2000_1999_`region'_uncond d_employmtg_2000_1999_`region';

};

*------------------------------------------------------------------------------------------------;

foreach spec in 1 2 3 4 {; /* begin of foreach spec */


   if `spec'==1 {;
      global controllist "$employmtlvls99 $workervars $plantvars";
   };
   else if `spec'==2 {;
      global controllist "$employmtlvls99 $workervars $plantvars $ustanvars";
   };
   else if `spec'==3 {;
      global controllist "$employmtlvls99 $nonustanvars $ustanvars";
   };
   else if `spec'==4 {;
      global controllist "$employmtlvls99 $nonustanvars $ustanvars $inonustanvars $iustanvars"; 
   };


   di _newline(2) "Sample `sample', ALL REGIONS, Specification `spec'";
   di _newline    "*************************************************************";

   
   logit separate $expansionvars $controllist, or; 
	mfx;
	est2vec allreglogit_s`sample'_spec`spec', e(r2_p);

}; /* end of foreach spec */


*------------------------------------------------------------------------------------------------;

/* matrix output */
/*---------------*/

# delimit ;

foreach sample in 1 2 3 {;
   foreach spec in 1 2 3 4 {; /* begin of foreach spec */
      foreach type in b se e {;
         matsave allreglogit_s`sample'_spec`spec'_`type', dropall p(estmat/$par) t(double) replace;
      }; /* type */
   }; /* spec */
}; /* sample */

*------------------------------------------------------------------------------------------------;

log close;
